# slack-beta-ti
One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.7.0
- Package version: 0.0.1
- Generator version: 7.11.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://api.slack.com/support](https://api.slack.com/support)

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import slack_beta_ti
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import slack_beta_ti
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import slack_beta_ti
from slack_beta_ti.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://slack.com/api
# See configuration.py for a list of all supported configuration parameters.
configuration = slack_beta_ti.Configuration(
    host = "https://slack.com/api"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

configuration.access_token = os.environ["ACCESS_TOKEN"]


# Enter a context with an instance of the API client
with slack_beta_ti.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = slack_beta_ti.AdminApi(api_client)
    token = 'token_example' # str | Authentication token. Requires scope: `admin.apps:write`
    app_id = 'app_id_example' # str | The id of the app to approve. (optional)
    request_id = 'request_id_example' # str | The id of the request to approve. (optional)
    team_id = 'team_id_example' # str |  (optional)

    try:
        api_response = api_instance.admin_apps_approve(token, app_id=app_id, request_id=request_id, team_id=team_id)
        print("The response of AdminApi->admin_apps_approve:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AdminApi->admin_apps_approve: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://slack.com/api*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdminApi* | [**admin_apps_approve**](docs/AdminApi.md#admin_apps_approve) | **POST** /admin.apps.approve | 
*AdminApi* | [**admin_apps_approved_list**](docs/AdminApi.md#admin_apps_approved_list) | **GET** /admin.apps.approved.list | 
*AdminApi* | [**admin_apps_requests_list**](docs/AdminApi.md#admin_apps_requests_list) | **GET** /admin.apps.requests.list | 
*AdminApi* | [**admin_apps_restrict**](docs/AdminApi.md#admin_apps_restrict) | **POST** /admin.apps.restrict | 
*AdminApi* | [**admin_apps_restricted_list**](docs/AdminApi.md#admin_apps_restricted_list) | **GET** /admin.apps.restricted.list | 
*AdminApi* | [**admin_conversations_archive**](docs/AdminApi.md#admin_conversations_archive) | **POST** /admin.conversations.archive | 
*AdminApi* | [**admin_conversations_convert_to_private**](docs/AdminApi.md#admin_conversations_convert_to_private) | **POST** /admin.conversations.convertToPrivate | 
*AdminApi* | [**admin_conversations_create**](docs/AdminApi.md#admin_conversations_create) | **POST** /admin.conversations.create | 
*AdminApi* | [**admin_conversations_delete**](docs/AdminApi.md#admin_conversations_delete) | **POST** /admin.conversations.delete | 
*AdminApi* | [**admin_conversations_disconnect_shared**](docs/AdminApi.md#admin_conversations_disconnect_shared) | **POST** /admin.conversations.disconnectShared | 
*AdminApi* | [**admin_conversations_ekm_list_original_connected_channel_info**](docs/AdminApi.md#admin_conversations_ekm_list_original_connected_channel_info) | **GET** /admin.conversations.ekm.listOriginalConnectedChannelInfo | 
*AdminApi* | [**admin_conversations_get_conversation_prefs**](docs/AdminApi.md#admin_conversations_get_conversation_prefs) | **GET** /admin.conversations.getConversationPrefs | 
*AdminApi* | [**admin_conversations_get_teams**](docs/AdminApi.md#admin_conversations_get_teams) | **GET** /admin.conversations.getTeams | 
*AdminApi* | [**admin_conversations_invite**](docs/AdminApi.md#admin_conversations_invite) | **POST** /admin.conversations.invite | 
*AdminApi* | [**admin_conversations_rename**](docs/AdminApi.md#admin_conversations_rename) | **POST** /admin.conversations.rename | 
*AdminApi* | [**admin_conversations_restrict_access_add_group**](docs/AdminApi.md#admin_conversations_restrict_access_add_group) | **POST** /admin.conversations.restrictAccess.addGroup | 
*AdminApi* | [**admin_conversations_restrict_access_list_groups**](docs/AdminApi.md#admin_conversations_restrict_access_list_groups) | **GET** /admin.conversations.restrictAccess.listGroups | 
*AdminApi* | [**admin_conversations_restrict_access_remove_group**](docs/AdminApi.md#admin_conversations_restrict_access_remove_group) | **POST** /admin.conversations.restrictAccess.removeGroup | 
*AdminApi* | [**admin_conversations_search**](docs/AdminApi.md#admin_conversations_search) | **GET** /admin.conversations.search | 
*AdminApi* | [**admin_conversations_set_conversation_prefs**](docs/AdminApi.md#admin_conversations_set_conversation_prefs) | **POST** /admin.conversations.setConversationPrefs | 
*AdminApi* | [**admin_conversations_set_teams**](docs/AdminApi.md#admin_conversations_set_teams) | **POST** /admin.conversations.setTeams | 
*AdminApi* | [**admin_conversations_unarchive**](docs/AdminApi.md#admin_conversations_unarchive) | **POST** /admin.conversations.unarchive | 
*AdminApi* | [**admin_emoji_add**](docs/AdminApi.md#admin_emoji_add) | **POST** /admin.emoji.add | 
*AdminApi* | [**admin_emoji_add_alias**](docs/AdminApi.md#admin_emoji_add_alias) | **POST** /admin.emoji.addAlias | 
*AdminApi* | [**admin_emoji_list**](docs/AdminApi.md#admin_emoji_list) | **GET** /admin.emoji.list | 
*AdminApi* | [**admin_emoji_remove**](docs/AdminApi.md#admin_emoji_remove) | **POST** /admin.emoji.remove | 
*AdminApi* | [**admin_emoji_rename**](docs/AdminApi.md#admin_emoji_rename) | **POST** /admin.emoji.rename | 
*AdminApi* | [**admin_invite_requests_approve**](docs/AdminApi.md#admin_invite_requests_approve) | **POST** /admin.inviteRequests.approve | 
*AdminApi* | [**admin_invite_requests_approved_list**](docs/AdminApi.md#admin_invite_requests_approved_list) | **GET** /admin.inviteRequests.approved.list | 
*AdminApi* | [**admin_invite_requests_denied_list**](docs/AdminApi.md#admin_invite_requests_denied_list) | **GET** /admin.inviteRequests.denied.list | 
*AdminApi* | [**admin_invite_requests_deny**](docs/AdminApi.md#admin_invite_requests_deny) | **POST** /admin.inviteRequests.deny | 
*AdminApi* | [**admin_invite_requests_list**](docs/AdminApi.md#admin_invite_requests_list) | **GET** /admin.inviteRequests.list | 
*AdminApi* | [**admin_teams_admins_list**](docs/AdminApi.md#admin_teams_admins_list) | **GET** /admin.teams.admins.list | 
*AdminApi* | [**admin_teams_create**](docs/AdminApi.md#admin_teams_create) | **POST** /admin.teams.create | 
*AdminApi* | [**admin_teams_list**](docs/AdminApi.md#admin_teams_list) | **GET** /admin.teams.list | 
*AdminApi* | [**admin_teams_owners_list**](docs/AdminApi.md#admin_teams_owners_list) | **GET** /admin.teams.owners.list | 
*AdminApi* | [**admin_teams_settings_info**](docs/AdminApi.md#admin_teams_settings_info) | **GET** /admin.teams.settings.info | 
*AdminApi* | [**admin_teams_settings_set_default_channels**](docs/AdminApi.md#admin_teams_settings_set_default_channels) | **POST** /admin.teams.settings.setDefaultChannels | 
*AdminApi* | [**admin_teams_settings_set_description**](docs/AdminApi.md#admin_teams_settings_set_description) | **POST** /admin.teams.settings.setDescription | 
*AdminApi* | [**admin_teams_settings_set_discoverability**](docs/AdminApi.md#admin_teams_settings_set_discoverability) | **POST** /admin.teams.settings.setDiscoverability | 
*AdminApi* | [**admin_teams_settings_set_icon**](docs/AdminApi.md#admin_teams_settings_set_icon) | **POST** /admin.teams.settings.setIcon | 
*AdminApi* | [**admin_teams_settings_set_name**](docs/AdminApi.md#admin_teams_settings_set_name) | **POST** /admin.teams.settings.setName | 
*AdminApi* | [**admin_usergroups_add_channels**](docs/AdminApi.md#admin_usergroups_add_channels) | **POST** /admin.usergroups.addChannels | 
*AdminApi* | [**admin_usergroups_add_teams**](docs/AdminApi.md#admin_usergroups_add_teams) | **POST** /admin.usergroups.addTeams | 
*AdminApi* | [**admin_usergroups_list_channels**](docs/AdminApi.md#admin_usergroups_list_channels) | **GET** /admin.usergroups.listChannels | 
*AdminApi* | [**admin_usergroups_remove_channels**](docs/AdminApi.md#admin_usergroups_remove_channels) | **POST** /admin.usergroups.removeChannels | 
*AdminApi* | [**admin_users_assign**](docs/AdminApi.md#admin_users_assign) | **POST** /admin.users.assign | 
*AdminApi* | [**admin_users_invite**](docs/AdminApi.md#admin_users_invite) | **POST** /admin.users.invite | 
*AdminApi* | [**admin_users_list**](docs/AdminApi.md#admin_users_list) | **GET** /admin.users.list | 
*AdminApi* | [**admin_users_remove**](docs/AdminApi.md#admin_users_remove) | **POST** /admin.users.remove | 
*AdminApi* | [**admin_users_session_invalidate**](docs/AdminApi.md#admin_users_session_invalidate) | **POST** /admin.users.session.invalidate | 
*AdminApi* | [**admin_users_session_reset**](docs/AdminApi.md#admin_users_session_reset) | **POST** /admin.users.session.reset | 
*AdminApi* | [**admin_users_set_admin**](docs/AdminApi.md#admin_users_set_admin) | **POST** /admin.users.setAdmin | 
*AdminApi* | [**admin_users_set_expiration**](docs/AdminApi.md#admin_users_set_expiration) | **POST** /admin.users.setExpiration | 
*AdminApi* | [**admin_users_set_owner**](docs/AdminApi.md#admin_users_set_owner) | **POST** /admin.users.setOwner | 
*AdminApi* | [**admin_users_set_regular**](docs/AdminApi.md#admin_users_set_regular) | **POST** /admin.users.setRegular | 
*AdminAppsApi* | [**admin_apps_approve**](docs/AdminAppsApi.md#admin_apps_approve) | **POST** /admin.apps.approve | 
*AdminAppsApi* | [**admin_apps_restrict**](docs/AdminAppsApi.md#admin_apps_restrict) | **POST** /admin.apps.restrict | 
*AdminAppsApprovedApi* | [**admin_apps_approved_list**](docs/AdminAppsApprovedApi.md#admin_apps_approved_list) | **GET** /admin.apps.approved.list | 
*AdminAppsRequestsApi* | [**admin_apps_requests_list**](docs/AdminAppsRequestsApi.md#admin_apps_requests_list) | **GET** /admin.apps.requests.list | 
*AdminAppsRestrictedApi* | [**admin_apps_restricted_list**](docs/AdminAppsRestrictedApi.md#admin_apps_restricted_list) | **GET** /admin.apps.restricted.list | 
*AdminConversationsApi* | [**admin_conversations_archive**](docs/AdminConversationsApi.md#admin_conversations_archive) | **POST** /admin.conversations.archive | 
*AdminConversationsApi* | [**admin_conversations_convert_to_private**](docs/AdminConversationsApi.md#admin_conversations_convert_to_private) | **POST** /admin.conversations.convertToPrivate | 
*AdminConversationsApi* | [**admin_conversations_create**](docs/AdminConversationsApi.md#admin_conversations_create) | **POST** /admin.conversations.create | 
*AdminConversationsApi* | [**admin_conversations_delete**](docs/AdminConversationsApi.md#admin_conversations_delete) | **POST** /admin.conversations.delete | 
*AdminConversationsApi* | [**admin_conversations_disconnect_shared**](docs/AdminConversationsApi.md#admin_conversations_disconnect_shared) | **POST** /admin.conversations.disconnectShared | 
*AdminConversationsApi* | [**admin_conversations_get_conversation_prefs**](docs/AdminConversationsApi.md#admin_conversations_get_conversation_prefs) | **GET** /admin.conversations.getConversationPrefs | 
*AdminConversationsApi* | [**admin_conversations_get_teams**](docs/AdminConversationsApi.md#admin_conversations_get_teams) | **GET** /admin.conversations.getTeams | 
*AdminConversationsApi* | [**admin_conversations_invite**](docs/AdminConversationsApi.md#admin_conversations_invite) | **POST** /admin.conversations.invite | 
*AdminConversationsApi* | [**admin_conversations_rename**](docs/AdminConversationsApi.md#admin_conversations_rename) | **POST** /admin.conversations.rename | 
*AdminConversationsApi* | [**admin_conversations_search**](docs/AdminConversationsApi.md#admin_conversations_search) | **GET** /admin.conversations.search | 
*AdminConversationsApi* | [**admin_conversations_set_conversation_prefs**](docs/AdminConversationsApi.md#admin_conversations_set_conversation_prefs) | **POST** /admin.conversations.setConversationPrefs | 
*AdminConversationsApi* | [**admin_conversations_set_teams**](docs/AdminConversationsApi.md#admin_conversations_set_teams) | **POST** /admin.conversations.setTeams | 
*AdminConversationsApi* | [**admin_conversations_unarchive**](docs/AdminConversationsApi.md#admin_conversations_unarchive) | **POST** /admin.conversations.unarchive | 
*AdminConversationsEkmApi* | [**admin_conversations_ekm_list_original_connected_channel_info**](docs/AdminConversationsEkmApi.md#admin_conversations_ekm_list_original_connected_channel_info) | **GET** /admin.conversations.ekm.listOriginalConnectedChannelInfo | 
*AdminConversationsRestrictAccessApi* | [**admin_conversations_restrict_access_add_group**](docs/AdminConversationsRestrictAccessApi.md#admin_conversations_restrict_access_add_group) | **POST** /admin.conversations.restrictAccess.addGroup | 
*AdminConversationsRestrictAccessApi* | [**admin_conversations_restrict_access_list_groups**](docs/AdminConversationsRestrictAccessApi.md#admin_conversations_restrict_access_list_groups) | **GET** /admin.conversations.restrictAccess.listGroups | 
*AdminConversationsRestrictAccessApi* | [**admin_conversations_restrict_access_remove_group**](docs/AdminConversationsRestrictAccessApi.md#admin_conversations_restrict_access_remove_group) | **POST** /admin.conversations.restrictAccess.removeGroup | 
*AdminEmojiApi* | [**admin_emoji_add**](docs/AdminEmojiApi.md#admin_emoji_add) | **POST** /admin.emoji.add | 
*AdminEmojiApi* | [**admin_emoji_add_alias**](docs/AdminEmojiApi.md#admin_emoji_add_alias) | **POST** /admin.emoji.addAlias | 
*AdminEmojiApi* | [**admin_emoji_list**](docs/AdminEmojiApi.md#admin_emoji_list) | **GET** /admin.emoji.list | 
*AdminEmojiApi* | [**admin_emoji_remove**](docs/AdminEmojiApi.md#admin_emoji_remove) | **POST** /admin.emoji.remove | 
*AdminEmojiApi* | [**admin_emoji_rename**](docs/AdminEmojiApi.md#admin_emoji_rename) | **POST** /admin.emoji.rename | 
*AdminInviteRequestsApi* | [**admin_invite_requests_approve**](docs/AdminInviteRequestsApi.md#admin_invite_requests_approve) | **POST** /admin.inviteRequests.approve | 
*AdminInviteRequestsApi* | [**admin_invite_requests_deny**](docs/AdminInviteRequestsApi.md#admin_invite_requests_deny) | **POST** /admin.inviteRequests.deny | 
*AdminInviteRequestsApi* | [**admin_invite_requests_list**](docs/AdminInviteRequestsApi.md#admin_invite_requests_list) | **GET** /admin.inviteRequests.list | 
*AdminInviteRequestsApprovedApi* | [**admin_invite_requests_approved_list**](docs/AdminInviteRequestsApprovedApi.md#admin_invite_requests_approved_list) | **GET** /admin.inviteRequests.approved.list | 
*AdminInviteRequestsDeniedApi* | [**admin_invite_requests_denied_list**](docs/AdminInviteRequestsDeniedApi.md#admin_invite_requests_denied_list) | **GET** /admin.inviteRequests.denied.list | 
*AdminTeamsApi* | [**admin_teams_create**](docs/AdminTeamsApi.md#admin_teams_create) | **POST** /admin.teams.create | 
*AdminTeamsApi* | [**admin_teams_list**](docs/AdminTeamsApi.md#admin_teams_list) | **GET** /admin.teams.list | 
*AdminTeamsAdminsApi* | [**admin_teams_admins_list**](docs/AdminTeamsAdminsApi.md#admin_teams_admins_list) | **GET** /admin.teams.admins.list | 
*AdminTeamsOwnersApi* | [**admin_teams_owners_list**](docs/AdminTeamsOwnersApi.md#admin_teams_owners_list) | **GET** /admin.teams.owners.list | 
*AdminTeamsSettingsApi* | [**admin_teams_settings_info**](docs/AdminTeamsSettingsApi.md#admin_teams_settings_info) | **GET** /admin.teams.settings.info | 
*AdminTeamsSettingsApi* | [**admin_teams_settings_set_default_channels**](docs/AdminTeamsSettingsApi.md#admin_teams_settings_set_default_channels) | **POST** /admin.teams.settings.setDefaultChannels | 
*AdminTeamsSettingsApi* | [**admin_teams_settings_set_description**](docs/AdminTeamsSettingsApi.md#admin_teams_settings_set_description) | **POST** /admin.teams.settings.setDescription | 
*AdminTeamsSettingsApi* | [**admin_teams_settings_set_discoverability**](docs/AdminTeamsSettingsApi.md#admin_teams_settings_set_discoverability) | **POST** /admin.teams.settings.setDiscoverability | 
*AdminTeamsSettingsApi* | [**admin_teams_settings_set_icon**](docs/AdminTeamsSettingsApi.md#admin_teams_settings_set_icon) | **POST** /admin.teams.settings.setIcon | 
*AdminTeamsSettingsApi* | [**admin_teams_settings_set_name**](docs/AdminTeamsSettingsApi.md#admin_teams_settings_set_name) | **POST** /admin.teams.settings.setName | 
*AdminUsergroupsApi* | [**admin_usergroups_add_channels**](docs/AdminUsergroupsApi.md#admin_usergroups_add_channels) | **POST** /admin.usergroups.addChannels | 
*AdminUsergroupsApi* | [**admin_usergroups_add_teams**](docs/AdminUsergroupsApi.md#admin_usergroups_add_teams) | **POST** /admin.usergroups.addTeams | 
*AdminUsergroupsApi* | [**admin_usergroups_list_channels**](docs/AdminUsergroupsApi.md#admin_usergroups_list_channels) | **GET** /admin.usergroups.listChannels | 
*AdminUsergroupsApi* | [**admin_usergroups_remove_channels**](docs/AdminUsergroupsApi.md#admin_usergroups_remove_channels) | **POST** /admin.usergroups.removeChannels | 
*AdminUsersApi* | [**admin_users_assign**](docs/AdminUsersApi.md#admin_users_assign) | **POST** /admin.users.assign | 
*AdminUsersApi* | [**admin_users_invite**](docs/AdminUsersApi.md#admin_users_invite) | **POST** /admin.users.invite | 
*AdminUsersApi* | [**admin_users_list**](docs/AdminUsersApi.md#admin_users_list) | **GET** /admin.users.list | 
*AdminUsersApi* | [**admin_users_remove**](docs/AdminUsersApi.md#admin_users_remove) | **POST** /admin.users.remove | 
*AdminUsersApi* | [**admin_users_set_admin**](docs/AdminUsersApi.md#admin_users_set_admin) | **POST** /admin.users.setAdmin | 
*AdminUsersApi* | [**admin_users_set_expiration**](docs/AdminUsersApi.md#admin_users_set_expiration) | **POST** /admin.users.setExpiration | 
*AdminUsersApi* | [**admin_users_set_owner**](docs/AdminUsersApi.md#admin_users_set_owner) | **POST** /admin.users.setOwner | 
*AdminUsersApi* | [**admin_users_set_regular**](docs/AdminUsersApi.md#admin_users_set_regular) | **POST** /admin.users.setRegular | 
*AdminUsersSessionApi* | [**admin_users_session_invalidate**](docs/AdminUsersSessionApi.md#admin_users_session_invalidate) | **POST** /admin.users.session.invalidate | 
*AdminUsersSessionApi* | [**admin_users_session_reset**](docs/AdminUsersSessionApi.md#admin_users_session_reset) | **POST** /admin.users.session.reset | 
*ApiApi* | [**api_test**](docs/ApiApi.md#api_test) | **GET** /api.test | 
*AppsApi* | [**apps_event_authorizations_list**](docs/AppsApi.md#apps_event_authorizations_list) | **GET** /apps.event.authorizations.list | 
*AppsApi* | [**apps_permissions_info**](docs/AppsApi.md#apps_permissions_info) | **GET** /apps.permissions.info | 
*AppsApi* | [**apps_permissions_request**](docs/AppsApi.md#apps_permissions_request) | **GET** /apps.permissions.request | 
*AppsApi* | [**apps_permissions_resources_list**](docs/AppsApi.md#apps_permissions_resources_list) | **GET** /apps.permissions.resources.list | 
*AppsApi* | [**apps_permissions_scopes_list**](docs/AppsApi.md#apps_permissions_scopes_list) | **GET** /apps.permissions.scopes.list | 
*AppsApi* | [**apps_permissions_users_list**](docs/AppsApi.md#apps_permissions_users_list) | **GET** /apps.permissions.users.list | 
*AppsApi* | [**apps_permissions_users_request**](docs/AppsApi.md#apps_permissions_users_request) | **GET** /apps.permissions.users.request | 
*AppsApi* | [**apps_uninstall**](docs/AppsApi.md#apps_uninstall) | **GET** /apps.uninstall | 
*AppsEventAuthorizationsApi* | [**apps_event_authorizations_list**](docs/AppsEventAuthorizationsApi.md#apps_event_authorizations_list) | **GET** /apps.event.authorizations.list | 
*AppsPermissionsApi* | [**apps_permissions_info**](docs/AppsPermissionsApi.md#apps_permissions_info) | **GET** /apps.permissions.info | 
*AppsPermissionsApi* | [**apps_permissions_request**](docs/AppsPermissionsApi.md#apps_permissions_request) | **GET** /apps.permissions.request | 
*AppsPermissionsResourcesApi* | [**apps_permissions_resources_list**](docs/AppsPermissionsResourcesApi.md#apps_permissions_resources_list) | **GET** /apps.permissions.resources.list | 
*AppsPermissionsScopesApi* | [**apps_permissions_scopes_list**](docs/AppsPermissionsScopesApi.md#apps_permissions_scopes_list) | **GET** /apps.permissions.scopes.list | 
*AppsPermissionsUsersApi* | [**apps_permissions_users_list**](docs/AppsPermissionsUsersApi.md#apps_permissions_users_list) | **GET** /apps.permissions.users.list | 
*AppsPermissionsUsersApi* | [**apps_permissions_users_request**](docs/AppsPermissionsUsersApi.md#apps_permissions_users_request) | **GET** /apps.permissions.users.request | 
*AuthApi* | [**auth_revoke**](docs/AuthApi.md#auth_revoke) | **GET** /auth.revoke | 
*AuthApi* | [**auth_test**](docs/AuthApi.md#auth_test) | **GET** /auth.test | 
*BotsApi* | [**bots_info**](docs/BotsApi.md#bots_info) | **GET** /bots.info | 
*CallsApi* | [**calls_add**](docs/CallsApi.md#calls_add) | **POST** /calls.add | 
*CallsApi* | [**calls_end**](docs/CallsApi.md#calls_end) | **POST** /calls.end | 
*CallsApi* | [**calls_info**](docs/CallsApi.md#calls_info) | **GET** /calls.info | 
*CallsApi* | [**calls_participants_add**](docs/CallsApi.md#calls_participants_add) | **POST** /calls.participants.add | 
*CallsApi* | [**calls_participants_remove**](docs/CallsApi.md#calls_participants_remove) | **POST** /calls.participants.remove | 
*CallsApi* | [**calls_update**](docs/CallsApi.md#calls_update) | **POST** /calls.update | 
*CallsParticipantsApi* | [**calls_participants_add**](docs/CallsParticipantsApi.md#calls_participants_add) | **POST** /calls.participants.add | 
*CallsParticipantsApi* | [**calls_participants_remove**](docs/CallsParticipantsApi.md#calls_participants_remove) | **POST** /calls.participants.remove | 
*ChatApi* | [**chat_delete**](docs/ChatApi.md#chat_delete) | **POST** /chat.delete | 
*ChatApi* | [**chat_delete_scheduled_message**](docs/ChatApi.md#chat_delete_scheduled_message) | **POST** /chat.deleteScheduledMessage | 
*ChatApi* | [**chat_get_permalink**](docs/ChatApi.md#chat_get_permalink) | **GET** /chat.getPermalink | 
*ChatApi* | [**chat_me_message**](docs/ChatApi.md#chat_me_message) | **POST** /chat.meMessage | 
*ChatApi* | [**chat_post_ephemeral**](docs/ChatApi.md#chat_post_ephemeral) | **POST** /chat.postEphemeral | 
*ChatApi* | [**chat_post_message**](docs/ChatApi.md#chat_post_message) | **POST** /chat.postMessage | 
*ChatApi* | [**chat_schedule_message**](docs/ChatApi.md#chat_schedule_message) | **POST** /chat.scheduleMessage | 
*ChatApi* | [**chat_scheduled_messages_list**](docs/ChatApi.md#chat_scheduled_messages_list) | **GET** /chat.scheduledMessages.list | 
*ChatApi* | [**chat_unfurl**](docs/ChatApi.md#chat_unfurl) | **POST** /chat.unfurl | 
*ChatApi* | [**chat_update**](docs/ChatApi.md#chat_update) | **POST** /chat.update | 
*ChatScheduledMessagesApi* | [**chat_scheduled_messages_list**](docs/ChatScheduledMessagesApi.md#chat_scheduled_messages_list) | **GET** /chat.scheduledMessages.list | 
*ConversationsApi* | [**conversations_archive**](docs/ConversationsApi.md#conversations_archive) | **POST** /conversations.archive | 
*ConversationsApi* | [**conversations_close**](docs/ConversationsApi.md#conversations_close) | **POST** /conversations.close | 
*ConversationsApi* | [**conversations_create**](docs/ConversationsApi.md#conversations_create) | **POST** /conversations.create | 
*ConversationsApi* | [**conversations_history**](docs/ConversationsApi.md#conversations_history) | **GET** /conversations.history | 
*ConversationsApi* | [**conversations_info**](docs/ConversationsApi.md#conversations_info) | **GET** /conversations.info | 
*ConversationsApi* | [**conversations_invite**](docs/ConversationsApi.md#conversations_invite) | **POST** /conversations.invite | 
*ConversationsApi* | [**conversations_join**](docs/ConversationsApi.md#conversations_join) | **POST** /conversations.join | 
*ConversationsApi* | [**conversations_kick**](docs/ConversationsApi.md#conversations_kick) | **POST** /conversations.kick | 
*ConversationsApi* | [**conversations_leave**](docs/ConversationsApi.md#conversations_leave) | **POST** /conversations.leave | 
*ConversationsApi* | [**conversations_list**](docs/ConversationsApi.md#conversations_list) | **GET** /conversations.list | 
*ConversationsApi* | [**conversations_mark**](docs/ConversationsApi.md#conversations_mark) | **POST** /conversations.mark | 
*ConversationsApi* | [**conversations_members**](docs/ConversationsApi.md#conversations_members) | **GET** /conversations.members | 
*ConversationsApi* | [**conversations_open**](docs/ConversationsApi.md#conversations_open) | **POST** /conversations.open | 
*ConversationsApi* | [**conversations_rename**](docs/ConversationsApi.md#conversations_rename) | **POST** /conversations.rename | 
*ConversationsApi* | [**conversations_replies**](docs/ConversationsApi.md#conversations_replies) | **GET** /conversations.replies | 
*ConversationsApi* | [**conversations_set_purpose**](docs/ConversationsApi.md#conversations_set_purpose) | **POST** /conversations.setPurpose | 
*ConversationsApi* | [**conversations_set_topic**](docs/ConversationsApi.md#conversations_set_topic) | **POST** /conversations.setTopic | 
*ConversationsApi* | [**conversations_unarchive**](docs/ConversationsApi.md#conversations_unarchive) | **POST** /conversations.unarchive | 
*DialogApi* | [**dialog_open**](docs/DialogApi.md#dialog_open) | **GET** /dialog.open | 
*DndApi* | [**dnd_end_dnd**](docs/DndApi.md#dnd_end_dnd) | **POST** /dnd.endDnd | 
*DndApi* | [**dnd_end_snooze**](docs/DndApi.md#dnd_end_snooze) | **POST** /dnd.endSnooze | 
*DndApi* | [**dnd_info**](docs/DndApi.md#dnd_info) | **GET** /dnd.info | 
*DndApi* | [**dnd_set_snooze**](docs/DndApi.md#dnd_set_snooze) | **POST** /dnd.setSnooze | 
*DndApi* | [**dnd_team_info**](docs/DndApi.md#dnd_team_info) | **GET** /dnd.teamInfo | 
*EmojiApi* | [**emoji_list**](docs/EmojiApi.md#emoji_list) | **GET** /emoji.list | 
*FilesApi* | [**files_comments_delete**](docs/FilesApi.md#files_comments_delete) | **POST** /files.comments.delete | 
*FilesApi* | [**files_delete**](docs/FilesApi.md#files_delete) | **POST** /files.delete | 
*FilesApi* | [**files_info**](docs/FilesApi.md#files_info) | **GET** /files.info | 
*FilesApi* | [**files_list**](docs/FilesApi.md#files_list) | **GET** /files.list | 
*FilesApi* | [**files_remote_add**](docs/FilesApi.md#files_remote_add) | **POST** /files.remote.add | 
*FilesApi* | [**files_remote_info**](docs/FilesApi.md#files_remote_info) | **GET** /files.remote.info | 
*FilesApi* | [**files_remote_list**](docs/FilesApi.md#files_remote_list) | **GET** /files.remote.list | 
*FilesApi* | [**files_remote_remove**](docs/FilesApi.md#files_remote_remove) | **POST** /files.remote.remove | 
*FilesApi* | [**files_remote_share**](docs/FilesApi.md#files_remote_share) | **GET** /files.remote.share | 
*FilesApi* | [**files_remote_update**](docs/FilesApi.md#files_remote_update) | **POST** /files.remote.update | 
*FilesApi* | [**files_revoke_public_url**](docs/FilesApi.md#files_revoke_public_url) | **POST** /files.revokePublicURL | 
*FilesApi* | [**files_shared_public_url**](docs/FilesApi.md#files_shared_public_url) | **POST** /files.sharedPublicURL | 
*FilesApi* | [**files_upload**](docs/FilesApi.md#files_upload) | **POST** /files.upload | 
*FilesCommentsApi* | [**files_comments_delete**](docs/FilesCommentsApi.md#files_comments_delete) | **POST** /files.comments.delete | 
*FilesRemoteApi* | [**files_remote_add**](docs/FilesRemoteApi.md#files_remote_add) | **POST** /files.remote.add | 
*FilesRemoteApi* | [**files_remote_info**](docs/FilesRemoteApi.md#files_remote_info) | **GET** /files.remote.info | 
*FilesRemoteApi* | [**files_remote_list**](docs/FilesRemoteApi.md#files_remote_list) | **GET** /files.remote.list | 
*FilesRemoteApi* | [**files_remote_remove**](docs/FilesRemoteApi.md#files_remote_remove) | **POST** /files.remote.remove | 
*FilesRemoteApi* | [**files_remote_share**](docs/FilesRemoteApi.md#files_remote_share) | **GET** /files.remote.share | 
*FilesRemoteApi* | [**files_remote_update**](docs/FilesRemoteApi.md#files_remote_update) | **POST** /files.remote.update | 
*MigrationApi* | [**migration_exchange**](docs/MigrationApi.md#migration_exchange) | **GET** /migration.exchange | 
*OauthApi* | [**oauth_access**](docs/OauthApi.md#oauth_access) | **GET** /oauth.access | 
*OauthApi* | [**oauth_token**](docs/OauthApi.md#oauth_token) | **GET** /oauth.token | 
*OauthApi* | [**oauth_v2_access**](docs/OauthApi.md#oauth_v2_access) | **GET** /oauth.v2.access | 
*OauthV2Api* | [**oauth_v2_access**](docs/OauthV2Api.md#oauth_v2_access) | **GET** /oauth.v2.access | 
*PinsApi* | [**pins_add**](docs/PinsApi.md#pins_add) | **POST** /pins.add | 
*PinsApi* | [**pins_list**](docs/PinsApi.md#pins_list) | **GET** /pins.list | 
*PinsApi* | [**pins_remove**](docs/PinsApi.md#pins_remove) | **POST** /pins.remove | 
*ReactionsApi* | [**reactions_add**](docs/ReactionsApi.md#reactions_add) | **POST** /reactions.add | 
*ReactionsApi* | [**reactions_get**](docs/ReactionsApi.md#reactions_get) | **GET** /reactions.get | 
*ReactionsApi* | [**reactions_list**](docs/ReactionsApi.md#reactions_list) | **GET** /reactions.list | 
*ReactionsApi* | [**reactions_remove**](docs/ReactionsApi.md#reactions_remove) | **POST** /reactions.remove | 
*RemindersApi* | [**reminders_add**](docs/RemindersApi.md#reminders_add) | **POST** /reminders.add | 
*RemindersApi* | [**reminders_complete**](docs/RemindersApi.md#reminders_complete) | **POST** /reminders.complete | 
*RemindersApi* | [**reminders_delete**](docs/RemindersApi.md#reminders_delete) | **POST** /reminders.delete | 
*RemindersApi* | [**reminders_info**](docs/RemindersApi.md#reminders_info) | **GET** /reminders.info | 
*RemindersApi* | [**reminders_list**](docs/RemindersApi.md#reminders_list) | **GET** /reminders.list | 
*RtmApi* | [**rtm_connect**](docs/RtmApi.md#rtm_connect) | **GET** /rtm.connect | 
*SearchApi* | [**search_messages**](docs/SearchApi.md#search_messages) | **GET** /search.messages | 
*StarsApi* | [**stars_add**](docs/StarsApi.md#stars_add) | **POST** /stars.add | 
*StarsApi* | [**stars_list**](docs/StarsApi.md#stars_list) | **GET** /stars.list | 
*StarsApi* | [**stars_remove**](docs/StarsApi.md#stars_remove) | **POST** /stars.remove | 
*TeamApi* | [**team_access_logs**](docs/TeamApi.md#team_access_logs) | **GET** /team.accessLogs | 
*TeamApi* | [**team_billable_info**](docs/TeamApi.md#team_billable_info) | **GET** /team.billableInfo | 
*TeamApi* | [**team_info**](docs/TeamApi.md#team_info) | **GET** /team.info | 
*TeamApi* | [**team_integration_logs**](docs/TeamApi.md#team_integration_logs) | **GET** /team.integrationLogs | 
*TeamApi* | [**team_profile_get**](docs/TeamApi.md#team_profile_get) | **GET** /team.profile.get | 
*TeamProfileApi* | [**team_profile_get**](docs/TeamProfileApi.md#team_profile_get) | **GET** /team.profile.get | 
*UsergroupsApi* | [**usergroups_create**](docs/UsergroupsApi.md#usergroups_create) | **POST** /usergroups.create | 
*UsergroupsApi* | [**usergroups_disable**](docs/UsergroupsApi.md#usergroups_disable) | **POST** /usergroups.disable | 
*UsergroupsApi* | [**usergroups_enable**](docs/UsergroupsApi.md#usergroups_enable) | **POST** /usergroups.enable | 
*UsergroupsApi* | [**usergroups_list**](docs/UsergroupsApi.md#usergroups_list) | **GET** /usergroups.list | 
*UsergroupsApi* | [**usergroups_update**](docs/UsergroupsApi.md#usergroups_update) | **POST** /usergroups.update | 
*UsergroupsApi* | [**usergroups_users_list**](docs/UsergroupsApi.md#usergroups_users_list) | **GET** /usergroups.users.list | 
*UsergroupsApi* | [**usergroups_users_update**](docs/UsergroupsApi.md#usergroups_users_update) | **POST** /usergroups.users.update | 
*UsergroupsUsersApi* | [**usergroups_users_list**](docs/UsergroupsUsersApi.md#usergroups_users_list) | **GET** /usergroups.users.list | 
*UsergroupsUsersApi* | [**usergroups_users_update**](docs/UsergroupsUsersApi.md#usergroups_users_update) | **POST** /usergroups.users.update | 
*UsersApi* | [**users_conversations**](docs/UsersApi.md#users_conversations) | **GET** /users.conversations | 
*UsersApi* | [**users_delete_photo**](docs/UsersApi.md#users_delete_photo) | **POST** /users.deletePhoto | 
*UsersApi* | [**users_get_presence**](docs/UsersApi.md#users_get_presence) | **GET** /users.getPresence | 
*UsersApi* | [**users_identity**](docs/UsersApi.md#users_identity) | **GET** /users.identity | 
*UsersApi* | [**users_info**](docs/UsersApi.md#users_info) | **GET** /users.info | 
*UsersApi* | [**users_list**](docs/UsersApi.md#users_list) | **GET** /users.list | 
*UsersApi* | [**users_lookup_by_email**](docs/UsersApi.md#users_lookup_by_email) | **GET** /users.lookupByEmail | 
*UsersApi* | [**users_profile_get**](docs/UsersApi.md#users_profile_get) | **GET** /users.profile.get | 
*UsersApi* | [**users_profile_set**](docs/UsersApi.md#users_profile_set) | **POST** /users.profile.set | 
*UsersApi* | [**users_set_active**](docs/UsersApi.md#users_set_active) | **POST** /users.setActive | 
*UsersApi* | [**users_set_photo**](docs/UsersApi.md#users_set_photo) | **POST** /users.setPhoto | 
*UsersApi* | [**users_set_presence**](docs/UsersApi.md#users_set_presence) | **POST** /users.setPresence | 
*UsersProfileApi* | [**users_profile_get**](docs/UsersProfileApi.md#users_profile_get) | **GET** /users.profile.get | 
*UsersProfileApi* | [**users_profile_set**](docs/UsersProfileApi.md#users_profile_set) | **POST** /users.profile.set | 
*ViewsApi* | [**views_open**](docs/ViewsApi.md#views_open) | **GET** /views.open | 
*ViewsApi* | [**views_publish**](docs/ViewsApi.md#views_publish) | **GET** /views.publish | 
*ViewsApi* | [**views_push**](docs/ViewsApi.md#views_push) | **GET** /views.push | 
*ViewsApi* | [**views_update**](docs/ViewsApi.md#views_update) | **GET** /views.update | 
*WorkflowsApi* | [**workflows_step_completed**](docs/WorkflowsApi.md#workflows_step_completed) | **GET** /workflows.stepCompleted | 
*WorkflowsApi* | [**workflows_step_failed**](docs/WorkflowsApi.md#workflows_step_failed) | **GET** /workflows.stepFailed | 
*WorkflowsApi* | [**workflows_update_step**](docs/WorkflowsApi.md#workflows_update_step) | **GET** /workflows.updateStep | 


## Documentation For Models

 - [APIMethodUsersGetPresence](docs/APIMethodUsersGetPresence.md)
 - [AdminAppsApproveRequest](docs/AdminAppsApproveRequest.md)
 - [AdminAppsRestrictRequest](docs/AdminAppsRestrictRequest.md)
 - [AdminConversationsArchiveErrorSchema](docs/AdminConversationsArchiveErrorSchema.md)
 - [AdminConversationsArchiveRequest](docs/AdminConversationsArchiveRequest.md)
 - [AdminConversationsArchiveSchema](docs/AdminConversationsArchiveSchema.md)
 - [AdminConversationsConvertToPrivateErrorSchema](docs/AdminConversationsConvertToPrivateErrorSchema.md)
 - [AdminConversationsConvertToPrivateRequest](docs/AdminConversationsConvertToPrivateRequest.md)
 - [AdminConversationsConvertToPrivateSchema](docs/AdminConversationsConvertToPrivateSchema.md)
 - [AdminConversationsCreateErrorSchema](docs/AdminConversationsCreateErrorSchema.md)
 - [AdminConversationsCreateRequest](docs/AdminConversationsCreateRequest.md)
 - [AdminConversationsCreateSchema](docs/AdminConversationsCreateSchema.md)
 - [AdminConversationsDeleteErrorSchema](docs/AdminConversationsDeleteErrorSchema.md)
 - [AdminConversationsDeleteRequest](docs/AdminConversationsDeleteRequest.md)
 - [AdminConversationsDeleteSchema](docs/AdminConversationsDeleteSchema.md)
 - [AdminConversationsDisconnectSharedErrorSchema](docs/AdminConversationsDisconnectSharedErrorSchema.md)
 - [AdminConversationsDisconnectSharedRequest](docs/AdminConversationsDisconnectSharedRequest.md)
 - [AdminConversationsGetConversationPrefsSchema](docs/AdminConversationsGetConversationPrefsSchema.md)
 - [AdminConversationsGetConversationPrefsSchemaPrefs](docs/AdminConversationsGetConversationPrefsSchemaPrefs.md)
 - [AdminConversationsGetConversationPrefsSchemaPrefsCanThread](docs/AdminConversationsGetConversationPrefsSchemaPrefsCanThread.md)
 - [AdminConversationsGetTeamsErrorSchema](docs/AdminConversationsGetTeamsErrorSchema.md)
 - [AdminConversationsGetTeamsSchema](docs/AdminConversationsGetTeamsSchema.md)
 - [AdminConversationsInviteErrorSchema](docs/AdminConversationsInviteErrorSchema.md)
 - [AdminConversationsInviteRequest](docs/AdminConversationsInviteRequest.md)
 - [AdminConversationsInviteSchema](docs/AdminConversationsInviteSchema.md)
 - [AdminConversationsRenameRequest](docs/AdminConversationsRenameRequest.md)
 - [AdminConversationsRenameSchema](docs/AdminConversationsRenameSchema.md)
 - [AdminConversationsRenameSchema1](docs/AdminConversationsRenameSchema1.md)
 - [AdminConversationsSearchErrorSchema](docs/AdminConversationsSearchErrorSchema.md)
 - [AdminConversationsSearchSchema](docs/AdminConversationsSearchSchema.md)
 - [AdminConversationsSetConversationPrefsErrorSchema](docs/AdminConversationsSetConversationPrefsErrorSchema.md)
 - [AdminConversationsSetConversationPrefsRequest](docs/AdminConversationsSetConversationPrefsRequest.md)
 - [AdminConversationsSetConversationPrefsSchema](docs/AdminConversationsSetConversationPrefsSchema.md)
 - [AdminConversationsSetTeamsRequest](docs/AdminConversationsSetTeamsRequest.md)
 - [AdminConversationsUnarchiveErrorSchema](docs/AdminConversationsUnarchiveErrorSchema.md)
 - [AdminConversationsUnarchiveErrorSchema1](docs/AdminConversationsUnarchiveErrorSchema1.md)
 - [AdminConversationsUnarchiveErrorSchema2](docs/AdminConversationsUnarchiveErrorSchema2.md)
 - [AdminConversationsUnarchiveRequest](docs/AdminConversationsUnarchiveRequest.md)
 - [AdminConversationsUnarchiveSchema](docs/AdminConversationsUnarchiveSchema.md)
 - [AdminInviteRequestsApproveRequest](docs/AdminInviteRequestsApproveRequest.md)
 - [AdminTeamsCreateRequest](docs/AdminTeamsCreateRequest.md)
 - [AdminTeamsSettingsSetDescriptionRequest](docs/AdminTeamsSettingsSetDescriptionRequest.md)
 - [AdminTeamsSettingsSetDiscoverabilityRequest](docs/AdminTeamsSettingsSetDiscoverabilityRequest.md)
 - [AdminTeamsSettingsSetNameRequest](docs/AdminTeamsSettingsSetNameRequest.md)
 - [AdminUsergroupsAddChannelsRequest](docs/AdminUsergroupsAddChannelsRequest.md)
 - [AdminUsergroupsAddTeamsRequest](docs/AdminUsergroupsAddTeamsRequest.md)
 - [AdminUsergroupsRemoveChannelsRequest](docs/AdminUsergroupsRemoveChannelsRequest.md)
 - [AdminUsersAssignRequest](docs/AdminUsersAssignRequest.md)
 - [AdminUsersInviteRequest](docs/AdminUsersInviteRequest.md)
 - [AdminUsersRemoveRequest](docs/AdminUsersRemoveRequest.md)
 - [AdminUsersSessionInvalidateRequest](docs/AdminUsersSessionInvalidateRequest.md)
 - [AdminUsersSessionResetRequest](docs/AdminUsersSessionResetRequest.md)
 - [AdminUsersSetAdminRequest](docs/AdminUsersSetAdminRequest.md)
 - [AdminUsersSetExpirationRequest](docs/AdminUsersSetExpirationRequest.md)
 - [AdminUsersSetOwnerRequest](docs/AdminUsersSetOwnerRequest.md)
 - [AdminUsersSetRegularRequest](docs/AdminUsersSetRegularRequest.md)
 - [ApiPermissionsScopesListSuccessSchema](docs/ApiPermissionsScopesListSuccessSchema.md)
 - [ApiTestErrorSchema](docs/ApiTestErrorSchema.md)
 - [ApiTestSuccessSchema](docs/ApiTestSuccessSchema.md)
 - [AppsPermissionsInfoErrorSchema](docs/AppsPermissionsInfoErrorSchema.md)
 - [AppsPermissionsInfoSchema](docs/AppsPermissionsInfoSchema.md)
 - [AppsPermissionsInfoSchemaInfo](docs/AppsPermissionsInfoSchemaInfo.md)
 - [AppsPermissionsInfoSchemaInfoAppHome](docs/AppsPermissionsInfoSchemaInfoAppHome.md)
 - [AppsPermissionsInfoSchemaInfoTeam](docs/AppsPermissionsInfoSchemaInfoTeam.md)
 - [AppsPermissionsRequestErrorSchema](docs/AppsPermissionsRequestErrorSchema.md)
 - [AppsPermissionsRequestSchema](docs/AppsPermissionsRequestSchema.md)
 - [AppsPermissionsResourcesListErrorSchema](docs/AppsPermissionsResourcesListErrorSchema.md)
 - [AppsPermissionsResourcesListSuccessSchema](docs/AppsPermissionsResourcesListSuccessSchema.md)
 - [AppsPermissionsResourcesListSuccessSchemaResourcesInner](docs/AppsPermissionsResourcesListSuccessSchemaResourcesInner.md)
 - [AppsPermissionsScopesListErrorSchema](docs/AppsPermissionsScopesListErrorSchema.md)
 - [AppsUninstallErrorSchema](docs/AppsUninstallErrorSchema.md)
 - [AppsUninstallSchema](docs/AppsUninstallSchema.md)
 - [AuthRevokeErrorSchema](docs/AuthRevokeErrorSchema.md)
 - [AuthRevokeSchema](docs/AuthRevokeSchema.md)
 - [AuthTestErrorSchema](docs/AuthTestErrorSchema.md)
 - [AuthTestSuccessSchema](docs/AuthTestSuccessSchema.md)
 - [BotsInfoErrorSchema](docs/BotsInfoErrorSchema.md)
 - [BotsInfoSchema](docs/BotsInfoSchema.md)
 - [CallsAddRequest](docs/CallsAddRequest.md)
 - [CallsEndRequest](docs/CallsEndRequest.md)
 - [CallsParticipantsAddRequest](docs/CallsParticipantsAddRequest.md)
 - [CallsParticipantsRemoveRequest](docs/CallsParticipantsRemoveRequest.md)
 - [CallsUpdateRequest](docs/CallsUpdateRequest.md)
 - [ChatDeleteErrorSchema](docs/ChatDeleteErrorSchema.md)
 - [ChatDeleteRequest](docs/ChatDeleteRequest.md)
 - [ChatDeleteScheduledMessageErrorSchema](docs/ChatDeleteScheduledMessageErrorSchema.md)
 - [ChatDeleteScheduledMessageRequest](docs/ChatDeleteScheduledMessageRequest.md)
 - [ChatDeleteScheduledMessageSchema](docs/ChatDeleteScheduledMessageSchema.md)
 - [ChatDeleteSuccessSchema](docs/ChatDeleteSuccessSchema.md)
 - [ChatGetPermalinkErrorSchema](docs/ChatGetPermalinkErrorSchema.md)
 - [ChatGetPermalinkSuccessSchema](docs/ChatGetPermalinkSuccessSchema.md)
 - [ChatMeMessageErrorSchema](docs/ChatMeMessageErrorSchema.md)
 - [ChatMeMessageRequest](docs/ChatMeMessageRequest.md)
 - [ChatMeMessageSchema](docs/ChatMeMessageSchema.md)
 - [ChatPostEphemeralErrorSchema](docs/ChatPostEphemeralErrorSchema.md)
 - [ChatPostEphemeralRequest](docs/ChatPostEphemeralRequest.md)
 - [ChatPostEphemeralSuccessSchema](docs/ChatPostEphemeralSuccessSchema.md)
 - [ChatPostMessageErrorSchema](docs/ChatPostMessageErrorSchema.md)
 - [ChatPostMessageRequest](docs/ChatPostMessageRequest.md)
 - [ChatPostMessageSuccessSchema](docs/ChatPostMessageSuccessSchema.md)
 - [ChatScheduleMessageErrorSchema](docs/ChatScheduleMessageErrorSchema.md)
 - [ChatScheduleMessageRequest](docs/ChatScheduleMessageRequest.md)
 - [ChatScheduleMessageSuccessSchema](docs/ChatScheduleMessageSuccessSchema.md)
 - [ChatScheduledMessagesListErrorSchema](docs/ChatScheduledMessagesListErrorSchema.md)
 - [ChatScheduledMessagesListSchema](docs/ChatScheduledMessagesListSchema.md)
 - [ChatUnfurlErrorSchema](docs/ChatUnfurlErrorSchema.md)
 - [ChatUnfurlRequest](docs/ChatUnfurlRequest.md)
 - [ChatUnfurlSuccessSchema](docs/ChatUnfurlSuccessSchema.md)
 - [ChatUpdateErrorSchema](docs/ChatUpdateErrorSchema.md)
 - [ChatUpdateRequest](docs/ChatUpdateRequest.md)
 - [ChatUpdateSuccessSchema](docs/ChatUpdateSuccessSchema.md)
 - [ConversationsArchiveErrorSchema](docs/ConversationsArchiveErrorSchema.md)
 - [ConversationsArchiveRequest](docs/ConversationsArchiveRequest.md)
 - [ConversationsArchiveSuccessSchema](docs/ConversationsArchiveSuccessSchema.md)
 - [ConversationsCloseErrorSchema](docs/ConversationsCloseErrorSchema.md)
 - [ConversationsCloseRequest](docs/ConversationsCloseRequest.md)
 - [ConversationsCloseSuccessSchema](docs/ConversationsCloseSuccessSchema.md)
 - [ConversationsCreateErrorSchema](docs/ConversationsCreateErrorSchema.md)
 - [ConversationsCreateRequest](docs/ConversationsCreateRequest.md)
 - [ConversationsCreateSuccessSchema](docs/ConversationsCreateSuccessSchema.md)
 - [ConversationsHistoryErrorSchema](docs/ConversationsHistoryErrorSchema.md)
 - [ConversationsHistorySuccessSchema](docs/ConversationsHistorySuccessSchema.md)
 - [ConversationsInfoErrorSchema](docs/ConversationsInfoErrorSchema.md)
 - [ConversationsInfoSuccessSchema](docs/ConversationsInfoSuccessSchema.md)
 - [ConversationsInviteErrorSchema](docs/ConversationsInviteErrorSchema.md)
 - [ConversationsInviteErrorSchema1](docs/ConversationsInviteErrorSchema1.md)
 - [ConversationsInviteRequest](docs/ConversationsInviteRequest.md)
 - [ConversationsJoinErrorSchema](docs/ConversationsJoinErrorSchema.md)
 - [ConversationsJoinRequest](docs/ConversationsJoinRequest.md)
 - [ConversationsJoinSuccessSchema](docs/ConversationsJoinSuccessSchema.md)
 - [ConversationsKickErrorSchema](docs/ConversationsKickErrorSchema.md)
 - [ConversationsKickRequest](docs/ConversationsKickRequest.md)
 - [ConversationsKickSuccessSchema](docs/ConversationsKickSuccessSchema.md)
 - [ConversationsLeaveErrorSchema](docs/ConversationsLeaveErrorSchema.md)
 - [ConversationsLeaveRequest](docs/ConversationsLeaveRequest.md)
 - [ConversationsLeaveSuccessSchema](docs/ConversationsLeaveSuccessSchema.md)
 - [ConversationsListErrorSchema](docs/ConversationsListErrorSchema.md)
 - [ConversationsListSuccessSchema](docs/ConversationsListSuccessSchema.md)
 - [ConversationsMarkErrorSchema](docs/ConversationsMarkErrorSchema.md)
 - [ConversationsMarkRequest](docs/ConversationsMarkRequest.md)
 - [ConversationsMarkSuccessSchema](docs/ConversationsMarkSuccessSchema.md)
 - [ConversationsMembersErrorSchema](docs/ConversationsMembersErrorSchema.md)
 - [ConversationsMembersSuccessSchema](docs/ConversationsMembersSuccessSchema.md)
 - [ConversationsOpenErrorSchema](docs/ConversationsOpenErrorSchema.md)
 - [ConversationsOpenRequest](docs/ConversationsOpenRequest.md)
 - [ConversationsOpenSuccessSchema](docs/ConversationsOpenSuccessSchema.md)
 - [ConversationsRenameErrorSchema](docs/ConversationsRenameErrorSchema.md)
 - [ConversationsRenameRequest](docs/ConversationsRenameRequest.md)
 - [ConversationsRenameSuccessSchema](docs/ConversationsRenameSuccessSchema.md)
 - [ConversationsRepliesErrorSchema](docs/ConversationsRepliesErrorSchema.md)
 - [ConversationsRepliesSuccessSchema](docs/ConversationsRepliesSuccessSchema.md)
 - [ConversationsSetPurposeErrorSchema](docs/ConversationsSetPurposeErrorSchema.md)
 - [ConversationsSetPurposeRequest](docs/ConversationsSetPurposeRequest.md)
 - [ConversationsSetPurposeSuccessSchema](docs/ConversationsSetPurposeSuccessSchema.md)
 - [ConversationsSetTopicErrorSchema](docs/ConversationsSetTopicErrorSchema.md)
 - [ConversationsSetTopicRequest](docs/ConversationsSetTopicRequest.md)
 - [ConversationsSetTopicSuccessSchema](docs/ConversationsSetTopicSuccessSchema.md)
 - [ConversationsUnarchiveErrorSchema](docs/ConversationsUnarchiveErrorSchema.md)
 - [ConversationsUnarchiveRequest](docs/ConversationsUnarchiveRequest.md)
 - [ConversationsUnarchiveSuccessSchema](docs/ConversationsUnarchiveSuccessSchema.md)
 - [DefaultErrorTemplate](docs/DefaultErrorTemplate.md)
 - [DefaultSuccessTemplate](docs/DefaultSuccessTemplate.md)
 - [DialogOpenErrorSchema](docs/DialogOpenErrorSchema.md)
 - [DialogOpenSchema](docs/DialogOpenSchema.md)
 - [DndEndDndErrorSchema](docs/DndEndDndErrorSchema.md)
 - [DndEndDndSchema](docs/DndEndDndSchema.md)
 - [DndEndSnoozeErrorSchema](docs/DndEndSnoozeErrorSchema.md)
 - [DndEndSnoozeSchema](docs/DndEndSnoozeSchema.md)
 - [DndInfoErrorSchema](docs/DndInfoErrorSchema.md)
 - [DndInfoSchema](docs/DndInfoSchema.md)
 - [DndSetSnoozeErrorSchema](docs/DndSetSnoozeErrorSchema.md)
 - [DndSetSnoozeSchema](docs/DndSetSnoozeSchema.md)
 - [FilesCommentsDeleteErrorSchema](docs/FilesCommentsDeleteErrorSchema.md)
 - [FilesCommentsDeleteRequest](docs/FilesCommentsDeleteRequest.md)
 - [FilesCommentsDeleteSchema](docs/FilesCommentsDeleteSchema.md)
 - [FilesDeleteErrorSchema](docs/FilesDeleteErrorSchema.md)
 - [FilesDeleteRequest](docs/FilesDeleteRequest.md)
 - [FilesDeleteSchema](docs/FilesDeleteSchema.md)
 - [FilesInfoErrorSchema](docs/FilesInfoErrorSchema.md)
 - [FilesInfoSchema](docs/FilesInfoSchema.md)
 - [FilesListErrorSchema](docs/FilesListErrorSchema.md)
 - [FilesListSchema](docs/FilesListSchema.md)
 - [FilesRevokePublicURLErrorSchema](docs/FilesRevokePublicURLErrorSchema.md)
 - [FilesRevokePublicURLRequest](docs/FilesRevokePublicURLRequest.md)
 - [FilesRevokePublicURLSchema](docs/FilesRevokePublicURLSchema.md)
 - [FilesSharedPublicURLErrorSchema](docs/FilesSharedPublicURLErrorSchema.md)
 - [FilesSharedPublicURLRequest](docs/FilesSharedPublicURLRequest.md)
 - [FilesSharedPublicURLSchema](docs/FilesSharedPublicURLSchema.md)
 - [FilesUploadErrorSchema](docs/FilesUploadErrorSchema.md)
 - [FilesUploadSchema](docs/FilesUploadSchema.md)
 - [MessageObject](docs/MessageObject.md)
 - [MigrationExchangeErrorSchema](docs/MigrationExchangeErrorSchema.md)
 - [MigrationExchangeSuccessSchema](docs/MigrationExchangeSuccessSchema.md)
 - [ObjsBotProfile](docs/ObjsBotProfile.md)
 - [ObjsChannel](docs/ObjsChannel.md)
 - [ObjsComment](docs/ObjsComment.md)
 - [ObjsEnterpriseUser](docs/ObjsEnterpriseUser.md)
 - [ObjsExternalOrgMigrations](docs/ObjsExternalOrgMigrations.md)
 - [ObjsExternalOrgMigrationsCurrentInner](docs/ObjsExternalOrgMigrationsCurrentInner.md)
 - [ObjsFile](docs/ObjsFile.md)
 - [ObjsIcon](docs/ObjsIcon.md)
 - [ObjsMessage](docs/ObjsMessage.md)
 - [ObjsPaging](docs/ObjsPaging.md)
 - [ObjsPrimaryOwner](docs/ObjsPrimaryOwner.md)
 - [ObjsReaction](docs/ObjsReaction.md)
 - [ObjsReminder](docs/ObjsReminder.md)
 - [ObjsResources](docs/ObjsResources.md)
 - [ObjsSubteam](docs/ObjsSubteam.md)
 - [ObjsTeam](docs/ObjsTeam.md)
 - [ObjsTeamProfileField](docs/ObjsTeamProfileField.md)
 - [ObjsTeamSsoProvider](docs/ObjsTeamSsoProvider.md)
 - [ObjsUserProfile](docs/ObjsUserProfile.md)
 - [ObjsUserProfileShort](docs/ObjsUserProfileShort.md)
 - [PinsAddErrorSchema](docs/PinsAddErrorSchema.md)
 - [PinsAddRequest](docs/PinsAddRequest.md)
 - [PinsAddSchema](docs/PinsAddSchema.md)
 - [PinsListErrorSchema](docs/PinsListErrorSchema.md)
 - [PinsRemoveErrorSchema](docs/PinsRemoveErrorSchema.md)
 - [PinsRemoveRequest](docs/PinsRemoveRequest.md)
 - [PinsRemoveSchema](docs/PinsRemoveSchema.md)
 - [ReactionsAddErrorSchema](docs/ReactionsAddErrorSchema.md)
 - [ReactionsAddRequest](docs/ReactionsAddRequest.md)
 - [ReactionsAddSchema](docs/ReactionsAddSchema.md)
 - [ReactionsGetErrorSchema](docs/ReactionsGetErrorSchema.md)
 - [ReactionsListErrorSchema](docs/ReactionsListErrorSchema.md)
 - [ReactionsListSchema](docs/ReactionsListSchema.md)
 - [ReactionsRemoveErrorSchema](docs/ReactionsRemoveErrorSchema.md)
 - [ReactionsRemoveRequest](docs/ReactionsRemoveRequest.md)
 - [ReactionsRemoveSchema](docs/ReactionsRemoveSchema.md)
 - [RemindersAddErrorSchema](docs/RemindersAddErrorSchema.md)
 - [RemindersAddRequest](docs/RemindersAddRequest.md)
 - [RemindersAddSchema](docs/RemindersAddSchema.md)
 - [RemindersCompleteErrorSchema](docs/RemindersCompleteErrorSchema.md)
 - [RemindersCompleteRequest](docs/RemindersCompleteRequest.md)
 - [RemindersCompleteSchema](docs/RemindersCompleteSchema.md)
 - [RemindersDeleteErrorSchema](docs/RemindersDeleteErrorSchema.md)
 - [RemindersDeleteRequest](docs/RemindersDeleteRequest.md)
 - [RemindersDeleteSchema](docs/RemindersDeleteSchema.md)
 - [RemindersInfoErrorSchema](docs/RemindersInfoErrorSchema.md)
 - [RemindersInfoSchema](docs/RemindersInfoSchema.md)
 - [RemindersListErrorSchema](docs/RemindersListErrorSchema.md)
 - [RemindersListSchema](docs/RemindersListSchema.md)
 - [ResponseMetadata](docs/ResponseMetadata.md)
 - [RtmConnectErrorSchema](docs/RtmConnectErrorSchema.md)
 - [RtmConnectSchema](docs/RtmConnectSchema.md)
 - [StarsAddErrorSchema](docs/StarsAddErrorSchema.md)
 - [StarsAddRequest](docs/StarsAddRequest.md)
 - [StarsAddSchema](docs/StarsAddSchema.md)
 - [StarsListErrorSchema](docs/StarsListErrorSchema.md)
 - [StarsListSchema](docs/StarsListSchema.md)
 - [StarsRemoveErrorSchema](docs/StarsRemoveErrorSchema.md)
 - [StarsRemoveRequest](docs/StarsRemoveRequest.md)
 - [StarsRemoveSchema](docs/StarsRemoveSchema.md)
 - [TeamAccessLogsErrorSchema](docs/TeamAccessLogsErrorSchema.md)
 - [TeamAccessLogsSchema](docs/TeamAccessLogsSchema.md)
 - [TeamInfoErrorSchema](docs/TeamInfoErrorSchema.md)
 - [TeamInfoSchema](docs/TeamInfoSchema.md)
 - [TeamIntegrationLogsErrorSchema](docs/TeamIntegrationLogsErrorSchema.md)
 - [TeamIntegrationLogsSchema](docs/TeamIntegrationLogsSchema.md)
 - [TeamProfileGetErrorSchema](docs/TeamProfileGetErrorSchema.md)
 - [TeamProfileGetSuccessSchema](docs/TeamProfileGetSuccessSchema.md)
 - [UsergroupsCreateErrorSchema](docs/UsergroupsCreateErrorSchema.md)
 - [UsergroupsCreateRequest](docs/UsergroupsCreateRequest.md)
 - [UsergroupsCreateSchema](docs/UsergroupsCreateSchema.md)
 - [UsergroupsDisableErrorSchema](docs/UsergroupsDisableErrorSchema.md)
 - [UsergroupsDisableRequest](docs/UsergroupsDisableRequest.md)
 - [UsergroupsDisableSchema](docs/UsergroupsDisableSchema.md)
 - [UsergroupsEnableErrorSchema](docs/UsergroupsEnableErrorSchema.md)
 - [UsergroupsEnableRequest](docs/UsergroupsEnableRequest.md)
 - [UsergroupsEnableSchema](docs/UsergroupsEnableSchema.md)
 - [UsergroupsListErrorSchema](docs/UsergroupsListErrorSchema.md)
 - [UsergroupsListSchema](docs/UsergroupsListSchema.md)
 - [UsergroupsUpdateErrorSchema](docs/UsergroupsUpdateErrorSchema.md)
 - [UsergroupsUpdateRequest](docs/UsergroupsUpdateRequest.md)
 - [UsergroupsUpdateSchema](docs/UsergroupsUpdateSchema.md)
 - [UsergroupsUsersListErrorSchema](docs/UsergroupsUsersListErrorSchema.md)
 - [UsergroupsUsersListSchema](docs/UsergroupsUsersListSchema.md)
 - [UsergroupsUsersUpdateErrorSchema](docs/UsergroupsUsersUpdateErrorSchema.md)
 - [UsergroupsUsersUpdateRequest](docs/UsergroupsUsersUpdateRequest.md)
 - [UsergroupsUsersUpdateSchema](docs/UsergroupsUsersUpdateSchema.md)
 - [UsersConversationsErrorSchema](docs/UsersConversationsErrorSchema.md)
 - [UsersConversationsSuccessSchema](docs/UsersConversationsSuccessSchema.md)
 - [UsersCountsErrorSchema](docs/UsersCountsErrorSchema.md)
 - [UsersDeletePhotoErrorSchema](docs/UsersDeletePhotoErrorSchema.md)
 - [UsersDeletePhotoSchema](docs/UsersDeletePhotoSchema.md)
 - [UsersIdentityErrorSchema](docs/UsersIdentityErrorSchema.md)
 - [UsersInfoErrorSchema](docs/UsersInfoErrorSchema.md)
 - [UsersInfoSuccessSchema](docs/UsersInfoSuccessSchema.md)
 - [UsersListErrorSchema](docs/UsersListErrorSchema.md)
 - [UsersListSchema](docs/UsersListSchema.md)
 - [UsersLookupByEmailErrorSchema](docs/UsersLookupByEmailErrorSchema.md)
 - [UsersLookupByEmailSuccessSchema](docs/UsersLookupByEmailSuccessSchema.md)
 - [UsersProfileGetErrorSchema](docs/UsersProfileGetErrorSchema.md)
 - [UsersProfileGetSchema](docs/UsersProfileGetSchema.md)
 - [UsersProfileSetErrorSchema](docs/UsersProfileSetErrorSchema.md)
 - [UsersProfileSetRequest](docs/UsersProfileSetRequest.md)
 - [UsersProfileSetSchema](docs/UsersProfileSetSchema.md)
 - [UsersSetActiveErrorSchema](docs/UsersSetActiveErrorSchema.md)
 - [UsersSetActiveSchema](docs/UsersSetActiveSchema.md)
 - [UsersSetPhotoErrorSchema](docs/UsersSetPhotoErrorSchema.md)
 - [UsersSetPhotoSchema](docs/UsersSetPhotoSchema.md)
 - [UsersSetPresenceErrorSchema](docs/UsersSetPresenceErrorSchema.md)
 - [UsersSetPresenceRequest](docs/UsersSetPresenceRequest.md)
 - [UsersSetPresenceSchema](docs/UsersSetPresenceSchema.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="slackAuth"></a>
### slackAuth

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://slack.com/oauth/authorize
- **Scopes**: 
 - **admin**: admin
 - **admin.apps:read**: admin.apps:read
 - **admin.apps:write**: admin.apps:write
 - **admin.conversations:read**: admin.conversations:read
 - **admin.conversations:write**: admin.conversations:write
 - **admin.invites:read**: admin.invites:read
 - **admin.invites:write**: admin.invites:write
 - **admin.teams:read**: admin.teams:read
 - **admin.teams:write**: admin.teams:write
 - **admin.usergroups:read**: admin.usergroups:read
 - **admin.usergroups:write**: admin.usergroups:write
 - **admin.users:read**: admin.users:read
 - **admin.users:write**: admin.users:write
 - **authorizations:read**: authorizations:read
 - **bot**: Bot user scope
 - **calls:read**: calls:read
 - **calls:write**: calls:write
 - **channels:history**: channels:history
 - **channels:manage**: channels:manage
 - **channels:read**: channels:read
 - **channels:write**: channels:write
 - **chat:write**: chat:write
 - **chat:write:bot**: Author messages as a bot
 - **chat:write:user**: Author messages as a user
 - **conversations:history**: conversations:history
 - **conversations:read**: conversations:read
 - **conversations:write**: conversations:write
 - **dnd:read**: dnd:read
 - **dnd:write**: dnd:write
 - **emoji:read**: emoji:read
 - **files:read**: files:read
 - **files:write:user**: files:write:user
 - **groups:history**: groups:history
 - **groups:read**: groups:read
 - **groups:write**: groups:write
 - **identity.basic**: identity.basic
 - **im:history**: im:history
 - **im:read**: im:read
 - **im:write**: im:write
 - **links:write**: links:write
 - **mpim:history**: mpim:history
 - **mpim:read**: mpim:read
 - **mpim:write**: mpim:write
 - **none**: No scope required
 - **pins:read**: pins:read
 - **pins:write**: pins:write
 - **reactions:read**: reactions:read
 - **reactions:write**: reactions:write
 - **reminders:read**: reminders:read
 - **reminders:write**: reminders:write
 - **remote_files:read**: remote_files:read
 - **remote_files:share**: remote_files:share
 - **remote_files:write**: remote_files:write
 - **rtm:stream**: rtm:stream
 - **search:read**: search:read
 - **stars:read**: stars:read
 - **stars:write**: stars:write
 - **team:read**: team:read
 - **tokens.basic**: tokens.basic
 - **usergroups:read**: usergroups:read
 - **usergroups:write**: usergroups:write
 - **users.profile:read**: users.profile:read
 - **users.profile:write**: users.profile:write
 - **users:read**: users:read
 - **users:read.email**: users:read.email
 - **users:write**: users:write
 - **workflow.steps:execute**: workflow.steps:execute


## Author




